api_method_map = {
    'asset/create': 'POST',
    'blacklist/create': 'POST',
    'blacklist/delete': 'POST',
    'blacklist/list': 'GET',
    'channel-role/create': 'POST',
    'channel-role/delete': 'POST',
    'channel-role/index': 'GET',
    'channel-role/update': 'POST',
    'channel/create': 'POST',
    'channel/delete': 'POST',
    'channel/list': 'GET',
    'channel/move-user': 'POST',
    'channel/view': 'GET',
    'direct-message/add-reaction': 'POST',
    'direct-message/create': 'POST',
    'direct-message/delete': 'POST',
    'direct-message/delete-reaction': 'POST',
    'direct-message/list': 'GET',
    'direct-message/reaction-list': 'GET',
    'direct-message/update': 'POST',
    'gateway/index': 'GET',
    'guild-emoji/create': 'POST',
    'guild-emoji/delete': 'POST',
    'guild-emoji/list': 'GET',
    'guild-emoji/update': 'POST',
    'guild-mute/create': 'POST',
    'guild-mute/delete': 'POST',
    'guild-mute/list': 'GET',
    'guild-role/create': 'POST',
    'guild-role/delete': 'POST',
    'guild-role/grant': 'POST',
    'guild-role/list': 'GET',
    'guild-role/revoke': 'POST',
    'guild-role/update': 'POST',
    'guild/kickout': 'POST',
    'guild/leave': 'POST',
    'guild/list': 'GET',
    'guild/nickname': 'POST',
    'guild/user-list': 'GET',
    'guild/view': 'GET',
    'intimacy/index': 'GET',
    'intimacy/update': 'POST',
    'invite/create': 'POST',
    'invite/delete': 'POST',
    'invite/list': 'GET',
    'message/add-reaction': 'POST',
    'message/create': 'POST',
    'message/delete': 'POST',
    'message/delete-reaction': 'POST',
    'message/list': 'GET',
    'message/reaction-list': 'GET',
    'message/update': 'POST',
    'message/view': 'GET',
    'user-chat/create': 'POST',
    'user-chat/delete': 'POST',
    'user-chat/list': 'GET',
    'user-chat/view': 'GET',
    'user/me': 'GET',
    'user/offline': 'POST',
    'user/view': 'GET'
}


def get_api_method(api: str) -> str:
    return api_method_map.get(api, "POST")



import asyncio
from io import StringIO
from typing import Any, Dict, Tuple, Optional

from nonebot.utils import logger_wrapper

from .exception import ActionFailed

log = logger_wrapper("Kook")


def _b2s(b: Optional[bool]) -> Optional[str]:
    """转换布尔值为字符串。"""
    return b if b is None else str(b).lower()


def code_to_emoji(emoji: str) -> str:
    return emoji.encode("unicode_escape")


ESCAPE_CHAR = "!()*-.:>[\]`~"


def escape_kmarkdown(content: str):
    """
    将文本中的kmarkdown标识符进行转义
    """
    with StringIO() as f:
        for c in content:
            if c in ESCAPE_CHAR:
                f.write('\\')
            f.write(c)
        return f.getvalue()


def unescape_kmarkdown(content: str):
    """
    去除kmarkdown中的转义字符
    """
    with StringIO() as f:
        i = 0
        while i < len(content):
            if content[i] == '\\':
                if i+1 < len(content) and content[i+1] in ESCAPE_CHAR:
                    f.write(content[i+1])
                    i += 2
                    continue

            f.write(content[i])
            i += 1
        return f.getvalue()


def _handle_api_result(result: Optional[Dict[str, Any]]) -> Any:
    """
    :说明:

      处理 API 请求返回值。

    :参数:

      * ``result: Optional[Dict[str, Any]]``: API 返回数据

    :返回:

        - ``Any``: API 调用返回数据

    :异常:

        - ``ActionFailed``: API 调用失败
    """
    if isinstance(result, dict):
        if result.get("code") != 0:
            raise ActionFailed(**result)
        return result.get("data")


class ResultStore:
    _seq = 1
    _futures: Dict[Tuple[str, int], asyncio.Future] = {}
    _sn_map = {}

    @classmethod
    def set_sn(cls, self_id: str, sn: int) -> None:
        cls._sn_map[self_id] = sn

    @classmethod
    def get_sn(cls, self_id: str) -> int:
        return cls._sn_map.get(self_id, 0)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['nonebot', 'nonebot.adapters.kook']

package_data = \
{'': ['*']}

install_requires = \
['aiohttp>=3.8.1,<4.0.0',
 'deprecated>=1.2.13,<2.0.0',
 'nonebot2>=2.0.0-beta.1,<3.0.0']

setup_kwargs = {
    'name': 'nonebot-adapter-kook',
    'version': '0.0.8',
    'description': 'Kook adapter for nonebot2',
    'long_description': '<p align="center">\n  <a"><img src="docs/logo2.png" width="500" alt="logo"></a>\n</p>\n\n<div align="center">\n\n# NoneBot-Adapter-Kook\n\n_✨ Kook协议适配 ✨_\n\n</div>\n\n## 个人工作繁忙时间不多， 欢迎有想法的各位共同维护仓库\n\n## Manual\n\n[使用指南](./MANUAL.md)\n',
    'author': 'Krysztal',
    'author_email': 'suibing112233@outlook.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/SUIBING112233/nonebot-adapter-kook',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7.3,<4.0.0',
}


setup(**setup_kwargs)
